// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.spellchecker.grazie.dictionary

import ai.grazie.spell.lists.WordList
import ai.grazie.spell.utils.Distances

internal class WordListAdapter : WordList, EditableWordListAdapter() {
  fun isAlien(word: String): Boolean {
    return dictionaries.values.all { it.contains(word) == null } && !aggregator.contains(word)
  }

  override fun contains(word: String, caseSensitive: Boolean): Boolean {
    val inDictionary = if (caseSensitive) {
      dictionaries.values.any { it.contains(word) ?: false }
    } else {
      val lowered = word.lowercase()
      // NOTE: dictionary may not contain lowercase form, but may contain any form in a different case
      // current dictionary interface does not support caseSensitive
      dictionaries.values.any { (it.contains(word) ?: false) || it.contains(lowered) ?: false }
    }

    return inDictionary || aggregator.contains(word, caseSensitive)
  }

  override fun suggest(word: String): LinkedHashSet<String> {
    val result = LinkedHashSet<String>()
    for (dictionary in dictionaries.values) {
      dictionary.consumeSuggestions(word) {
        val distance = Distances.levenshtein.distance(word, it, SimpleWordList.MAX_LEVENSHTEIN_DISTANCE + 1)
        if (distance <= SimpleWordList.MAX_LEVENSHTEIN_DISTANCE) {
          result.add(it)
        }
      }
    }

    result.addAll(aggregator.suggest(word))
    return result
  }
}
